@@ -27,7 +27,7 @@ class DeviceName(Enum):
     Nokia_Lumia_520 = "Nokia Lumia 520"
     Microsoft_Lumia_550 = "Microsoft Lumia 550"
     Microsoft_Lumia_950 = "Microsoft Lumia 950"
-    Galaxy_S3 = "Galaxy S III"
+    Galaxy_S3 = "Galaxy S3"
     Galaxy_S5 = "Galaxy S5"
     Kindle_Fire_HDX = "Kindle Fire HDX"
     iPad_Mini = "iPad Mini"
@@ -35,10 +35,38 @@ class DeviceName(Enum):
     Nexus_10 = "Nexus 10"
     Nexus_7 = "Nexus 7"
     Galaxy_Note_3 = "Galaxy Note 3"
-    Galaxy_Note_2 = "Galaxy Note II"
+    Galaxy_Note_2 = "Galaxy Note 2"
     Laptop_with_touch = "Laptop with touch"
     Laptop_with_HiDPI_screen = "Laptop with HiDPI screen"
     Laptop_with_MDPI_screen = "Laptop with MDPI screen"
+    Pixel_3 = "Pixel 3"
+    Pixel_3_XL = "Pixel 3 XL"
+    Pixel_4 = "Pixel 4"
+    Pixel_4_XL = "Pixel 4 XL"
+    iPad_6th_Gen = "iPad 6th Gen"
+    iPad_7th_Gen = "iPad 7th Gen"
+    iPad_Air_2 = "iPad Air 2"
+    iPhone_11 = "iPhone 11"
+    iPhone_11_Pro = "iPhone 11 Pro"
+    iPhone_11_Pro_Max = "iPhone 11 Pro Max"
+    iPhone_XR = "iPhone XR"
+    iPhone_XS = "iPhone XS"
+    iPhone_XS_Max = "iPhone XS Max"
+    LG_G6 = "LG G6"
+    Galaxy_A5 = "Galaxy A5"
+    Galaxy_Note_10 = "Galaxy Note 10"
+    Galaxy_Note_10_Plus = "Galaxy Note 10 Plus"
+    Galaxy_Note_4 = "Galaxy Note 4"
+    Galaxy_Note_8 = "Galaxy Note 8"
+    Galaxy_Note_9 = "Galaxy Note 9"
+    Galaxy_S10 = "Galaxy S10"
+    Galaxy_S8 = "Galaxy S8"
+    Galaxy_S8_Plus = "Galaxy S8 Plus"
+    Galaxy_S9_Plus = "Galaxy S9 Plus"
+    Galaxy_S10_Plus = "Galaxy S10 Plus"
+    Galaxy_S9 = "Galaxy S9"
+    OnePlus_7T = "OnePlus 7T"
+    OnePlus_7T_Pro = "OnePlus 7T Pro"
 
 
 class IosDeviceName(Enum):
